@@ -172,10 +172,11 @@ layout = [
 ]
 
 
-_AVAILABLE_PRINTER_SCHEMAS = []
+_AVAILABLE_PRINTER_SCHEMAS = []  # type: list[str]
 
 
 def unmapPrinterURI(value, encoding=()):
+    # type: (list[bytes], tuple[str, ...]) -> tuple[str, str]
     if not value:
         return (u'', u'')
     schema = u''
@@ -191,6 +192,7 @@ def unmapPrinterURI(value, encoding=()):
 
 
 def mapPrinterURI(value, encoding=()):
+    # type: (list[str], tuple[str, ...]) -> bytes
     return u''.join(value).encode(*encoding)
 
 
@@ -210,20 +212,29 @@ mapping.register('ACLtype', 'univentionPrinterACLtype', None, univention.admin.m
 class object(univention.admin.handlers.simpleLdap):
     module = module
 
-    def __init__(self, co, lo, position, dn='', superordinate=None, attributes=[]):
+    def __init__(
+        self,
+        co,  # type: None
+        lo,  # type: univention.admin.uldap.access
+        position,  # type: univention.admin.uldap.position
+        dn='',  # type: str
+        superordinate=None,  # type: univention.admin.handlers.simpleLdap | None
+        attributes=None,  # type: univention.admin.handlers._Attributes | None
+    ):  # type: (...) -> None
         # find the printer uris
         if not _AVAILABLE_PRINTER_SCHEMAS:
-            printer_uris = univention.admin.modules.get('settings/printeruri').lookup(co, lo, '')
+            printer_uris = univention.admin.modules._get('settings/printeruri').lookup(co, lo, '')
             for uri in printer_uris:
                 _AVAILABLE_PRINTER_SCHEMAS.extend(uri['printeruri'])
 
         univention.admin.handlers.simpleLdap.__init__(self, co, lo, position, dn, superordinate, attributes=attributes)
 
     def open(self):
+        # type: () -> None
         # find the producer
         univention.admin.handlers.simpleLdap.open(self)
         if self['model']:
-            models = univention.admin.modules.get('settings/printermodel').lookup(None, self.lo, filter_format('printerModel="%s*', [self['model']]))
+            models = univention.admin.modules._get('settings/printermodel').lookup(None, self.lo, filter_format('printerModel="%s*', [self['model']]))
             log.debug("printermodel: %s", models)
             if not models or len(models) > 1:
                 self['producer'] = []
@@ -233,11 +244,13 @@ class object(univention.admin.handlers.simpleLdap):
         self.save()
 
     def _ldap_pre_ready(self):
+        # type: () -> None
         super(object, self)._ldap_pre_ready()
         if (not self.exists() or self.hasChanged('uri')) and self['uri']:
             self._sanitize_uri()
 
     def _sanitize_uri(self):
+        # type: () -> None
         protocol, host = self['uri']
 
         for schema in _AVAILABLE_PRINTER_SCHEMAS:
@@ -256,6 +269,7 @@ class object(univention.admin.handlers.simpleLdap):
             self['uri'][1] = re.sub(r'^/+', '', self['uri'][1])
 
     def _ldap_pre_remove(self):  # check for last member in printerclass
+        # type: () -> None
         super(object, self)._ldap_pre_remove()
         printergroups_filter = '(&(objectClass=univentionPrinterGroup)(|%s))' % (''.join(filter_format('(univentionPrinterSpoolHost=%s)', [x]) for x in self.info['spoolHost']))
         rm_attrib = []
@@ -266,7 +280,7 @@ class object(univention.admin.handlers.simpleLdap):
                     if len(member_list['univentionPrinterGroupMember']) < 2:
                         raise univention.admin.uexceptions.emptyPrinterGroup(_('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')})
 
-        printergroup_module = univention.admin.modules.get('shares/printergroup')
+        printergroup_module = univention.admin.modules._get('shares/printergroup')
         for rm_dn in rm_attrib:
             printergroup_object = univention.admin.objects.get(printergroup_module, None, self.lo, position='', dn=rm_dn)
             printergroup_object.open()
